@@ -24,6 +24,7 @@ language, and more.
 from __future__ import absolute_import
 
 import json
+from os.path import basename
 from .watson_service import WatsonService
 
 ##############################################################################
@@ -42,7 +43,7 @@ class LanguageTranslatorV3(WatsonService):
             url=default_url,
             username=None,
             password=None,
-            iam_api_key=None,
+            iam_apikey=None,
             iam_access_token=None,
             iam_url=None,
     ):
@@ -76,7 +77,7 @@ class LanguageTranslatorV3(WatsonService):
                Bluemix, the credentials will be automatically loaded from the
                `VCAP_SERVICES` environment variable.
 
-        :param str iam_api_key: An API key that can be used to request IAM tokens. If
+        :param str iam_apikey: An API key that can be used to request IAM tokens. If
                this API key is provided, the SDK will manage the token and handle the
                refreshing.
 
@@ -86,7 +87,7 @@ class LanguageTranslatorV3(WatsonService):
                made with an expired token will fail.
 
         :param str iam_url: An optional URL for the IAM service API. Defaults to
-               'https://iam.ng.bluemix.net/identity/token'.
+               'https://iam.bluemix.net/identity/token'.
         """
 
         WatsonService.__init__(
@@ -95,7 +96,7 @@ class LanguageTranslatorV3(WatsonService):
             url=url,
             username=username,
             password=password,
-            iam_api_key=iam_api_key,
+            iam_apikey=iam_apikey,
             iam_access_token=iam_access_token,
             iam_url=iam_url,
             use_vcap_services=True)
@@ -105,11 +106,7 @@ class LanguageTranslatorV3(WatsonService):
     # Translation
     #########################
 
-    def translate(self,
-                  text,
-                  model_id=None,
-                  source=None,
-                  target=None,
+    def translate(self, text, model_id=None, source=None, target=None,
                   **kwargs):
         """
         Translate.
@@ -118,31 +115,31 @@ class LanguageTranslatorV3(WatsonService):
 
         :param list[str] text: Input text in UTF-8 encoding. Multiple entries will result
         in multiple translations in the response.
-        :param str model_id: Model ID of the translation model to use. If this is
-        specified, the **source** and **target** parameters will be ignored. The method
-        requires either a model ID or both the **source** and **target** parameters.
-        :param str source: Language code of the source text language. Use with `target` as
-        an alternative way to select a translation model. When `source` and `target` are
-        set, and a model ID is not set, the system chooses a default model for the
-        language pair (usually the model based on the news domain).
-        :param str target: Language code of the translation target language. Use with
-        source as an alternative way to select a translation model.
+        :param str model_id: A globally unique string that identifies the underlying model
+        that is used for translation.
+        :param str source: Translation source language code.
+        :param str target: Translation target language code.
         :param dict headers: A `dict` containing the request headers
-        :return: A `dict` containing the `TranslationResult` response.
-        :rtype: dict
+        :return: A `DetailedResponse` containing the result, headers and HTTP status code.
+        :rtype: DetailedResponse
         """
+
         if text is None:
             raise ValueError('text must be provided')
+
         headers = {}
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+
         params = {'version': self.version}
+
         data = {
             'text': text,
             'model_id': model_id,
             'source': source,
             'target': target
         }
+
         url = '/v3/translate'
         response = self.request(
             method='POST',
@@ -165,17 +162,22 @@ class LanguageTranslatorV3(WatsonService):
 
         :param str text: Input text in UTF-8 format.
         :param dict headers: A `dict` containing the request headers
-        :return: A `dict` containing the `IdentifiedLanguages` response.
-        :rtype: dict
+        :return: A `DetailedResponse` containing the result, headers and HTTP status code.
+        :rtype: DetailedResponse
         """
+
         if text is None:
             raise ValueError('text must be provided')
+
         headers = {}
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+
         params = {'version': self.version}
+
         data = text
-        headers = {'content-type': 'text/plain'}
+        headers['content-type'] = 'text/plain'
+
         url = '/v3/identify'
         response = self.request(
             method='POST',
@@ -194,13 +196,16 @@ class LanguageTranslatorV3(WatsonService):
         example, `en` for English or `es` for Spanish) and name of each language.
 
         :param dict headers: A `dict` containing the request headers
-        :return: A `dict` containing the `IdentifiableLanguages` response.
-        :rtype: dict
+        :return: A `DetailedResponse` containing the result, headers and HTTP status code.
+        :rtype: DetailedResponse
         """
+
         headers = {}
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+
         params = {'version': self.version}
+
         url = '/v3/identifiable_languages'
         response = self.request(
             method='GET',
@@ -259,45 +264,46 @@ class LanguageTranslatorV3(WatsonService):
         :param str forced_glossary_filename: The filename for forced_glossary.
         :param str parallel_corpus_filename: The filename for parallel_corpus.
         :param dict headers: A `dict` containing the request headers
-        :return: A `dict` containing the `TranslationModel` response.
-        :rtype: dict
+        :return: A `DetailedResponse` containing the result, headers and HTTP status code.
+        :rtype: DetailedResponse
         """
+
         if base_model_id is None:
             raise ValueError('base_model_id must be provided')
+
         headers = {}
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+
         params = {
             'version': self.version,
             'base_model_id': base_model_id,
             'name': name
         }
-        forced_glossary_tuple = None
+
+        form_data = {}
         if forced_glossary:
-            if not forced_glossary_filename and hasattr(
-                    forced_glossary, 'name'):
-                forced_glossary_filename = forced_glossary.name
-            mime_type = 'application/octet-stream'
-            forced_glossary_tuple = (forced_glossary_filename, forced_glossary,
-                                     mime_type)
-        parallel_corpus_tuple = None
+            if not forced_glossary_filename and hasattr(forced_glossary,
+                                                        'name'):
+                forced_glossary_filename = basename(forced_glossary.name)
+            form_data['forced_glossary'] = (forced_glossary_filename,
+                                            forced_glossary,
+                                            'application/octet-stream')
         if parallel_corpus:
-            if not parallel_corpus_filename and hasattr(
-                    parallel_corpus, 'name'):
-                parallel_corpus_filename = parallel_corpus.name
-            mime_type = 'application/octet-stream'
-            parallel_corpus_tuple = (parallel_corpus_filename, parallel_corpus,
-                                     mime_type)
+            if not parallel_corpus_filename and hasattr(parallel_corpus,
+                                                        'name'):
+                parallel_corpus_filename = basename(parallel_corpus.name)
+            form_data['parallel_corpus'] = (parallel_corpus_filename,
+                                            parallel_corpus,
+                                            'application/octet-stream')
+
         url = '/v3/models'
         response = self.request(
             method='POST',
             url=url,
             headers=headers,
             params=params,
-            files={
-                'forced_glossary': forced_glossary_tuple,
-                'parallel_corpus': parallel_corpus_tuple
-            },
+            files=form_data,
             accept_json=True)
         return response
 
@@ -309,15 +315,19 @@ class LanguageTranslatorV3(WatsonService):
 
         :param str model_id: Model ID of the model to delete.
         :param dict headers: A `dict` containing the request headers
-        :return: A `dict` containing the `DeleteModelResult` response.
-        :rtype: dict
+        :return: A `DetailedResponse` containing the result, headers and HTTP status code.
+        :rtype: DetailedResponse
         """
+
         if model_id is None:
             raise ValueError('model_id must be provided')
+
         headers = {}
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+
         params = {'version': self.version}
+
         url = '/v3/models/{0}'.format(*self._encode_path_vars(model_id))
         response = self.request(
             method='DELETE',
@@ -337,15 +347,19 @@ class LanguageTranslatorV3(WatsonService):
 
         :param str model_id: Model ID of the model to get.
         :param dict headers: A `dict` containing the request headers
-        :return: A `dict` containing the `TranslationModel` response.
-        :rtype: dict
+        :return: A `DetailedResponse` containing the result, headers and HTTP status code.
+        :rtype: DetailedResponse
         """
+
         if model_id is None:
             raise ValueError('model_id must be provided')
+
         headers = {}
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+
         params = {'version': self.version}
+
         url = '/v3/models/{0}'.format(*self._encode_path_vars(model_id))
         response = self.request(
             method='GET',
@@ -373,18 +387,21 @@ class LanguageTranslatorV3(WatsonService):
         this to `false`. There is exactly one default model per language pair, the IBM
         provided base model.
         :param dict headers: A `dict` containing the request headers
-        :return: A `dict` containing the `TranslationModels` response.
-        :rtype: dict
+        :return: A `DetailedResponse` containing the result, headers and HTTP status code.
+        :rtype: DetailedResponse
         """
+
         headers = {}
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+
         params = {
             'version': self.version,
             'source': source,
             'target': target,
             'default': default_models
         }
+
         url = '/v3/models'
         response = self.request(
             method='GET',
