@@ -24,6 +24,7 @@ from __future__ import absolute_import
 
 import json
 from .watson_service import datetime_to_string, string_to_datetime
+from os.path import basename
 from .watson_service import WatsonService
 
 ##############################################################################
@@ -41,7 +42,7 @@ class NaturalLanguageClassifierV1(WatsonService):
             url=default_url,
             username=None,
             password=None,
-            iam_api_key=None,
+            iam_apikey=None,
             iam_access_token=None,
             iam_url=None,
     ):
@@ -64,7 +65,7 @@ class NaturalLanguageClassifierV1(WatsonService):
                Bluemix, the credentials will be automatically loaded from the
                `VCAP_SERVICES` environment variable.
 
-        :param str iam_api_key: An API key that can be used to request IAM tokens. If
+        :param str iam_apikey: An API key that can be used to request IAM tokens. If
                this API key is provided, the SDK will manage the token and handle the
                refreshing.
 
@@ -74,7 +75,7 @@ class NaturalLanguageClassifierV1(WatsonService):
                made with an expired token will fail.
 
         :param str iam_url: An optional URL for the IAM service API. Defaults to
-               'https://iam.ng.bluemix.net/identity/token'.
+               'https://iam.bluemix.net/identity/token'.
         """
 
         WatsonService.__init__(
@@ -83,7 +84,7 @@ class NaturalLanguageClassifierV1(WatsonService):
             url=url,
             username=username,
             password=password,
-            iam_api_key=iam_api_key,
+            iam_apikey=iam_apikey,
             iam_access_token=iam_access_token,
             iam_url=iam_url,
             use_vcap_services=True)
@@ -100,19 +101,23 @@ class NaturalLanguageClassifierV1(WatsonService):
         can use the classifier to classify text.
 
         :param str classifier_id: Classifier ID to use.
-        :param str text: The submitted phrase.
+        :param str text: The submitted phrase. The maximum length is 2048 characters.
         :param dict headers: A `dict` containing the request headers
-        :return: A `dict` containing the `Classification` response.
-        :rtype: dict
+        :return: A `DetailedResponse` containing the result, headers and HTTP status code.
+        :rtype: DetailedResponse
         """
+
         if classifier_id is None:
             raise ValueError('classifier_id must be provided')
         if text is None:
             raise ValueError('text must be provided')
+
         headers = {}
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+
         data = {'text': text}
+
         url = '/v1/classifiers/{0}/classify'.format(
             *self._encode_path_vars(classifier_id))
         response = self.request(
@@ -134,20 +139,22 @@ class NaturalLanguageClassifierV1(WatsonService):
         :param str classifier_id: Classifier ID to use.
         :param list[ClassifyInput] collection: The submitted phrases.
         :param dict headers: A `dict` containing the request headers
-        :return: A `dict` containing the `ClassificationCollection` response.
-        :rtype: dict
+        :return: A `DetailedResponse` containing the result, headers and HTTP status code.
+        :rtype: DetailedResponse
         """
+
         if classifier_id is None:
             raise ValueError('classifier_id must be provided')
         if collection is None:
             raise ValueError('collection must be provided')
-        collection = [
-            self._convert_model(x, ClassifyInput) for x in collection
-        ]
+        collection = [self._convert_model(x, ClassifyInput) for x in collection]
+
         headers = {}
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+
         data = {'collection': collection}
+
         url = '/v1/classifiers/{0}/classify_collection'.format(
             *self._encode_path_vars(classifier_id))
         response = self.request(
@@ -181,40 +188,41 @@ class NaturalLanguageClassifierV1(WatsonService):
         (`de`), Italian (`it`), Japanese (`ja`), Korean (`ko`), Brazilian Portuguese
         (`pt`), and Spanish (`es`).
         :param file training_data: Training data in CSV format. Each text value must have
-        at least one class. The data can include up to 20,000 records. For details, see
-        [Data
+        at least one class. The data can include up to 3,000 classes and 20,000 records.
+        For details, see [Data
         preparation](https://console.bluemix.net/docs/services/natural-language-classifier/using-your-data.html).
         :param str metadata_filename: The filename for training_metadata.
         :param str training_data_filename: The filename for training_data.
         :param dict headers: A `dict` containing the request headers
-        :return: A `dict` containing the `Classifier` response.
-        :rtype: dict
+        :return: A `DetailedResponse` containing the result, headers and HTTP status code.
+        :rtype: DetailedResponse
         """
+
         if metadata is None:
             raise ValueError('metadata must be provided')
         if training_data is None:
             raise ValueError('training_data must be provided')
+
         headers = {}
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+
+        form_data = {}
         if not metadata_filename and hasattr(metadata, 'name'):
-            metadata_filename = metadata.name
-        mime_type = 'application/json'
-        metadata_tuple = (metadata_filename, metadata, mime_type)
+            metadata_filename = basename(metadata.name)
+        form_data['training_metadata'] = (metadata_filename, metadata,
+                                          'application/json')
         if not training_data_filename and hasattr(training_data, 'name'):
-            training_data_filename = training_data.name
-        mime_type = 'text/csv'
-        training_data_tuple = (training_data_filename, training_data,
-                               mime_type)
+            training_data_filename = basename(training_data.name)
+        form_data['training_data'] = (training_data_filename, training_data,
+                                      'text/csv')
+
         url = '/v1/classifiers'
         response = self.request(
             method='POST',
             url=url,
             headers=headers,
-            files={
-                'training_metadata': metadata_tuple,
-                'training_data': training_data_tuple
-            },
+            files=form_data,
             accept_json=True)
         return response
 
@@ -224,18 +232,22 @@ class NaturalLanguageClassifierV1(WatsonService):
 
         :param str classifier_id: Classifier ID to delete.
         :param dict headers: A `dict` containing the request headers
-        :rtype: None
+        :return: A `DetailedResponse` containing the result, headers and HTTP status code.
+        :rtype: DetailedResponse
         """
+
         if classifier_id is None:
             raise ValueError('classifier_id must be provided')
+
         headers = {}
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+
         url = '/v1/classifiers/{0}'.format(
             *self._encode_path_vars(classifier_id))
-        self.request(
+        response = self.request(
             method='DELETE', url=url, headers=headers, accept_json=True)
-        return None
+        return response
 
     def get_classifier(self, classifier_id, **kwargs):
         """
@@ -245,14 +257,17 @@ class NaturalLanguageClassifierV1(WatsonService):
 
         :param str classifier_id: Classifier ID to query.
         :param dict headers: A `dict` containing the request headers
-        :return: A `dict` containing the `Classifier` response.
-        :rtype: dict
+        :return: A `DetailedResponse` containing the result, headers and HTTP status code.
+        :rtype: DetailedResponse
         """
+
         if classifier_id is None:
             raise ValueError('classifier_id must be provided')
+
         headers = {}
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+
         url = '/v1/classifiers/{0}'.format(
             *self._encode_path_vars(classifier_id))
         response = self.request(
@@ -266,12 +281,14 @@ class NaturalLanguageClassifierV1(WatsonService):
         Returns an empty array if no classifiers are available.
 
         :param dict headers: A `dict` containing the request headers
-        :return: A `dict` containing the `ClassifierList` response.
-        :rtype: dict
+        :return: A `DetailedResponse` containing the result, headers and HTTP status code.
+        :rtype: DetailedResponse
         """
+
         headers = {}
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+
         url = '/v1/classifiers'
         response = self.request(
             method='GET', url=url, headers=headers, accept_json=True)
@@ -644,14 +661,14 @@ class ClassifyInput(object):
     """
     Request payload to classify.
 
-    :attr str text: The submitted phrase.
+    :attr str text: The submitted phrase. The maximum length is 2048 characters.
     """
 
     def __init__(self, text):
         """
         Initialize a ClassifyInput object.
 
-        :param str text: The submitted phrase.
+        :param str text: The submitted phrase. The maximum length is 2048 characters.
         """
         self.text = text
 
@@ -692,7 +709,8 @@ class CollectionItem(object):
     """
     Response from the classifier for a phrase in a collection.
 
-    :attr str text: (optional) The submitted phrase.
+    :attr str text: (optional) The submitted phrase. The maximum length is 2048
+    characters.
     :attr str top_class: (optional) The class with the highest confidence.
     :attr list[ClassifiedClass] classes: (optional) An array of up to ten class-confidence
     pairs sorted in descending order of confidence.
@@ -702,7 +720,8 @@ class CollectionItem(object):
         """
         Initialize a CollectionItem object.
 
-        :param str text: (optional) The submitted phrase.
+        :param str text: (optional) The submitted phrase. The maximum length is 2048
+        characters.
         :param str top_class: (optional) The class with the highest confidence.
         :param list[ClassifiedClass] classes: (optional) An array of up to ten
         class-confidence pairs sorted in descending order of confidence.
