@@ -25,12 +25,12 @@ consumption preferences based on the results of its analysis and, for JSON conte
 timestamped, can report temporal behavior.
 * For information about the meaning of the models that the service uses to describe
 personality characteristics, see [Personality
-models](https://console.bluemix.net/docs/services/personality-insights/models.html).
+models](/docs/services/personality-insights/models.html).
 * For information about the meaning of the consumption preferences, see [Consumption
-preferences](https://console.bluemix.net/docs/services/personality-insights/preferences.html).
-**Note:** Request logging is disabled for the Personality Insights service. The service
-neither logs nor retains data from requests and responses, regardless of whether the
-`X-Watson-Learning-Opt-Out` request header is set.
+preferences](/docs/services/personality-insights/preferences.html).
+**Note:** Request logging is disabled for the Personality Insights service. Regardless of
+whether you set the `X-Watson-Learning-Opt-Out` request header, the service does not log
+or retain data from requests and responses.
 """
 
 from __future__ import absolute_import
@@ -54,7 +54,7 @@ class PersonalityInsightsV3(WatsonService):
             url=default_url,
             username=None,
             password=None,
-            iam_api_key=None,
+            iam_apikey=None,
             iam_access_token=None,
             iam_url=None,
     ):
@@ -88,7 +88,7 @@ class PersonalityInsightsV3(WatsonService):
                Bluemix, the credentials will be automatically loaded from the
                `VCAP_SERVICES` environment variable.
 
-        :param str iam_api_key: An API key that can be used to request IAM tokens. If
+        :param str iam_apikey: An API key that can be used to request IAM tokens. If
                this API key is provided, the SDK will manage the token and handle the
                refreshing.
 
@@ -98,7 +98,7 @@ class PersonalityInsightsV3(WatsonService):
                made with an expired token will fail.
 
         :param str iam_url: An optional URL for the IAM service API. Defaults to
-               'https://iam.ng.bluemix.net/identity/token'.
+               'https://iam.bluemix.net/identity/token'.
         """
 
         WatsonService.__init__(
@@ -107,7 +107,7 @@ class PersonalityInsightsV3(WatsonService):
             url=url,
             username=username,
             password=password,
-            iam_api_key=iam_api_key,
+            iam_apikey=iam_apikey,
             iam_access_token=iam_access_token,
             iam_url=iam_url,
             use_vcap_services=True)
@@ -119,9 +119,9 @@ class PersonalityInsightsV3(WatsonService):
 
     def profile(self,
                 content,
-                content_type='application/json',
+                content_type,
+                accept=None,
                 content_language=None,
-                accept='application/json',
                 accept_language=None,
                 raw_scores=None,
                 csv_headers=None,
@@ -132,35 +132,44 @@ class PersonalityInsightsV3(WatsonService):
 
         Generates a personality profile for the author of the input text. The service
         accepts a maximum of 20 MB of input content, but it requires much less text to
-        produce an accurate profile; for more information, see [Providing sufficient
-        input](https://console.bluemix.net/docs/services/personality-insights/input.html#sufficient).
-        The service analyzes text in Arabic, English, Japanese, Korean, or Spanish and
-        returns its results in a variety of languages. You can provide plain text, HTML,
-        or JSON input by specifying the **Content-Type** parameter; the default is
-        `text/plain`. Request a JSON or comma-separated values (CSV) response by
-        specifying the **Accept** parameter; CSV output includes a fixed number of columns
-        and optional headers.
-        Per the JSON specification, the default character encoding for JSON content is
-        effectively always UTF-8; per the HTTP specification, the default encoding for
-        plain text and HTML is ISO-8859-1 (effectively, the ASCII character set). When
-        specifying a content type of plain text or HTML, include the `charset` parameter
-        to indicate the character encoding of the input text; for example: `Content-Type:
-        text/plain;charset=utf-8`.
-        For detailed information about calling the service and the responses it can
-        generate, see [Requesting a
-        profile](https://console.bluemix.net/docs/services/personality-insights/input.html),
-        [Understanding a JSON
-        profile](https://console.bluemix.net/docs/services/personality-insights/output.html),
-        and [Understanding a CSV
-        profile](https://console.bluemix.net/docs/services/personality-insights/output-csv.html).
+        produce an accurate profile. The service can analyze text in Arabic, English,
+        Japanese, Korean, or Spanish. It can return its results in a variety of languages.
+        **See also:**
+        * [Requesting a profile](/docs/services/personality-insights/input.html)
+        * [Providing sufficient
+        input](/docs/services/personality-insights/input.html#sufficient)
+        ### Content types
+         You can provide input content as plain text (`text/plain`), HTML (`text/html`),
+        or JSON (`application/json`) by specifying the **Content-Type** parameter. The
+        default is `text/plain`.
+        * Per the JSON specification, the default character encoding for JSON content is
+        effectively always UTF-8.
+        * Per the HTTP specification, the default encoding for plain text and HTML is
+        ISO-8859-1 (effectively, the ASCII character set).
+        When specifying a content type of plain text or HTML, include the `charset`
+        parameter to indicate the character encoding of the input text; for example,
+        `Content-Type: text/plain;charset=utf-8`.
+        **See also:** [Specifying request and response
+        formats](/docs/services/personality-insights/input.html#formats)
+        ### Accept types
+         You must request a response as JSON (`application/json`) or comma-separated
+        values (`text/csv`) by specifying the **Accept** parameter. CSV output includes a
+        fixed number of columns. Set the **csv_headers** parameter to `true` to request
+        optional column headers for CSV output.
+        **See also:**
+        * [Understanding a JSON profile](/docs/services/personality-insights/output.html)
+        * [Understanding a CSV
+        profile](/docs/services/personality-insights/output-csv.html).
 
         :param Content content: A maximum of 20 MB of content to analyze, though the
         service requires much less text; for more information, see [Providing sufficient
-        input](https://console.bluemix.net/docs/services/personality-insights/input.html#sufficient).
-        For JSON input, provide an object of type `Content`.
-        :param str content_type: The type of the input: application/json, text/html, or
-        text/plain. A character encoding can be specified by including a `charset`
-        parameter. For example, 'text/html;charset=utf-8'.
+        input](/docs/services/personality-insights/input.html#sufficient). For JSON input,
+        provide an object of type `Content`.
+        :param str content_type: The type of the input. For more information, see
+        **Content types** in the method description.
+        Default: `text/plain`.
+        :param str accept: The type of the response. For more information, see **Accept
+        types** in the method description.
         :param str content_language: The language of the input text for the request:
         Arabic, English, Japanese, Korean, or Spanish. Regional variants are treated as
         their parent language; for example, `en-US` is interpreted as `en`.
@@ -172,9 +181,6 @@ class PersonalityInsightsV3(WatsonService):
         items that specify a different language are ignored; omit this parameter to base
         the language on the specification of the content items. You can specify any
         combination of languages for **Content-Language** and **Accept-Language**.
-        :param str accept: The type of the response: application/json or text/csv. A
-        character encoding can be specified by including a `charset` parameter. For
-        example, 'text/csv;charset=utf-8'.
         :param str accept_language: The desired language of the response. For
         two-character arguments, regional variants are treated as their parent language;
         for example, `en-US` is interpreted as `en`. You can specify any combination of
@@ -184,35 +190,42 @@ class PersonalityInsightsV3(WatsonService):
         sample population. By default, only normalized percentiles are returned.
         :param bool csv_headers: Indicates whether column labels are returned with a CSV
         response. By default, no column labels are returned. Applies only when the
-        **Accept** parameter is set to `text/csv`.
+        response type is CSV (`text/csv`).
         :param bool consumption_preferences: Indicates whether consumption preferences are
         returned with the results. By default, no consumption preferences are returned.
         :param dict headers: A `dict` containing the request headers
-        :return: A `dict` containing the `Profile` response.
-        :rtype: dict
+        :return: A `DetailedResponse` containing the result, headers and HTTP status code.
+        :rtype: DetailedResponse
         """
+
         if content is None:
             raise ValueError('content must be provided')
         if content_type is None:
             raise ValueError('content_type must be provided')
+        if isinstance(content, Content):
+            content = self._convert_model(content, Content)
+
         headers = {
+            'Accept': accept,
             'Content-Type': content_type,
             'Content-Language': content_language,
-            'Accept-Language': accept_language,
-            'Accept': accept
+            'Accept-Language': accept_language
         }
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+
         params = {
             'version': self.version,
             'raw_scores': raw_scores,
             'csv_headers': csv_headers,
             'consumption_preferences': consumption_preferences
         }
+
         if content_type == 'application/json' and isinstance(content, dict):
             data = json.dumps(content)
         else:
             data = content
+
         url = '/v3/profile'
         response = self.request(
             method='POST',
@@ -283,8 +296,7 @@ class Behavior(object):
             args['percentage'] = _dict.get('percentage')
         else:
             raise ValueError(
-                'Required property \'percentage\' not present in Behavior JSON'
-            )
+                'Required property \'percentage\' not present in Behavior JSON')
         return cls(**args)
 
     def _to_dict(self):
@@ -638,8 +650,7 @@ class ContentItem(object):
             args['content'] = _dict.get('content')
         else:
             raise ValueError(
-                'Required property \'content\' not present in ContentItem JSON'
-            )
+                'Required property \'content\' not present in ContentItem JSON')
         if 'id' in _dict:
             args['id'] = _dict.get('id')
         if 'created' in _dict:
@@ -797,10 +808,9 @@ class Profile(object):
             ]
         else:
             raise ValueError(
-                'Required property \'personality\' not present in Profile JSON'
-            )
+                'Required property \'personality\' not present in Profile JSON')
         if 'needs' in _dict:
-            args['needs'] = [Trait._from_dict(x) for x in _dict.get('needs')]
+            args['needs'] = [Trait._from_dict(x) for x in (_dict.get('needs'))]
         else:
             raise ValueError(
                 'Required property \'needs\' not present in Profile JSON')
