@@ -20,9 +20,9 @@ sentence levels. You can use the service to understand how your written communic
 perceived and then to improve the tone of your communications. Businesses can use the
 service to learn the tone of their customers' communications and to respond to each
 customer appropriately, or to understand and improve their customer conversations.
-**Note:** Request logging is disabled for the Tone Analyzer service. The service neither
-logs nor retains data from requests and responses, regardless of whether the
-`X-Watson-Learning-Opt-Out` request header is set.
+**Note:** Request logging is disabled for the Tone Analyzer service. Regardless of whether
+you set the `X-Watson-Learning-Opt-Out` request header, the service does not log or retain
+data from requests and responses.
 """
 
 from __future__ import absolute_import
@@ -46,7 +46,7 @@ class ToneAnalyzerV3(WatsonService):
             url=default_url,
             username=None,
             password=None,
-            iam_api_key=None,
+            iam_apikey=None,
             iam_access_token=None,
             iam_url=None,
     ):
@@ -80,7 +80,7 @@ class ToneAnalyzerV3(WatsonService):
                Bluemix, the credentials will be automatically loaded from the
                `VCAP_SERVICES` environment variable.
 
-        :param str iam_api_key: An API key that can be used to request IAM tokens. If
+        :param str iam_apikey: An API key that can be used to request IAM tokens. If
                this API key is provided, the SDK will manage the token and handle the
                refreshing.
 
@@ -90,7 +90,7 @@ class ToneAnalyzerV3(WatsonService):
                made with an expired token will fail.
 
         :param str iam_url: An optional URL for the IAM service API. Defaults to
-               'https://iam.ng.bluemix.net/identity/token'.
+               'https://iam.bluemix.net/identity/token'.
         """
 
         WatsonService.__init__(
@@ -99,7 +99,7 @@ class ToneAnalyzerV3(WatsonService):
             url=url,
             username=username,
             password=password,
-            iam_api_key=iam_api_key,
+            iam_apikey=iam_apikey,
             iam_access_token=iam_access_token,
             iam_url=iam_url,
             use_vcap_services=True)
@@ -111,7 +111,7 @@ class ToneAnalyzerV3(WatsonService):
 
     def tone(self,
              tone_input,
-             content_type,
+             content_type=None,
              sentences=None,
              tones=None,
              content_language=None,
@@ -135,6 +135,8 @@ class ToneAnalyzerV3(WatsonService):
         to indicate the character encoding of the input text; for example: `Content-Type:
         text/plain;charset=utf-8`. For `text/html`, the service removes HTML tags and
         analyzes only the textual content.
+        **See also:** [Using the general-purpose
+        endpoint](/docs/services/tone-analyzer/using-tone.html#using-the-general-purpose-endpoint).
 
         :param ToneInput tone_input: JSON, plain text, or HTML input that contains the
         content to be analyzed. For JSON input, provide an object of type `ToneInput`.
@@ -163,15 +165,15 @@ class ToneAnalyzerV3(WatsonService):
         for example, `en-US` is interpreted as `en`. You can use different languages for
         **Content-Language** and **Accept-Language**.
         :param dict headers: A `dict` containing the request headers
-        :return: A `dict` containing the `ToneAnalysis` response.
-        :rtype: dict
+        :return: A `DetailedResponse` containing the result, headers and HTTP status code.
+        :rtype: DetailedResponse
         """
+
         if tone_input is None:
             raise ValueError('tone_input must be provided')
-        if content_type is None:
-            raise ValueError('content_type must be provided')
         if isinstance(tone_input, ToneInput):
             tone_input = self._convert_model(tone_input, ToneInput)
+
         headers = {
             'Content-Type': content_type,
             'Content-Language': content_language,
@@ -179,15 +181,18 @@ class ToneAnalyzerV3(WatsonService):
         }
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+
         params = {
             'version': self.version,
             'sentences': sentences,
             'tones': self._convert_list(tones)
         }
+
         if content_type == 'application/json' and isinstance(tone_input, dict):
             data = json.dumps(tone_input)
         else:
             data = tone_input
+
         url = '/v3/tone'
         response = self.request(
             method='POST',
@@ -214,9 +219,10 @@ class ToneAnalyzerV3(WatsonService):
         overall content and analyzes only the first 50 utterances. If you submit a single
         utterance that contains more than 500 characters, the service returns an error for
         that utterance and does not analyze the utterance. The request fails if all
-        utterances have more than 500 characters.
-        Per the JSON specification, the default character encoding for JSON content is
-        effectively always UTF-8.
+        utterances have more than 500 characters. Per the JSON specification, the default
+        character encoding for JSON content is effectively always UTF-8.
+        **See also:** [Using the customer-engagement
+        endpoint](/docs/services/tone-analyzer/using-tone-chat.html#using-the-customer-engagement-endpoint).
 
         :param list[Utterance] utterances: An array of `Utterance` objects that provides
         the input content that the service is to analyze.
@@ -232,20 +238,25 @@ class ToneAnalyzerV3(WatsonService):
         for example, `en-US` is interpreted as `en`. You can use different languages for
         **Content-Language** and **Accept-Language**.
         :param dict headers: A `dict` containing the request headers
-        :return: A `dict` containing the `UtteranceAnalyses` response.
-        :rtype: dict
+        :return: A `DetailedResponse` containing the result, headers and HTTP status code.
+        :rtype: DetailedResponse
         """
+
         if utterances is None:
             raise ValueError('utterances must be provided')
         utterances = [self._convert_model(x, Utterance) for x in utterances]
+
         headers = {
             'Content-Language': content_language,
             'Accept-Language': accept_language
         }
         if 'headers' in kwargs:
             headers.update(kwargs.get('headers'))
+
         params = {'version': self.version}
+
         data = {'utterances': utterances}
+
         url = '/v3/tone_chat'
         response = self.request(
             method='POST',
@@ -264,7 +275,8 @@ class ToneAnalyzerV3(WatsonService):
 
 class DocumentAnalysis(object):
     """
-    DocumentAnalysis.
+    An object of type `DocumentAnalysis` that provides the results of the analysis for the
+    full input document.
 
     :attr list[ToneScore] tones: (optional) **`2017-09-21`:** An array of `ToneScore`
     objects that provides the results of the analysis for each qualifying tone of the
@@ -631,9 +643,8 @@ class ToneChatScore(object):
     :attr float score: The score for the tone in the range of 0.5 to 1. A score greater
     than 0.75 indicates a high likelihood that the tone is perceived in the utterance.
     :attr str tone_id: The unique, non-localized identifier of the tone for the results.
-    The service can return results for the following tone IDs: `sad`, `frustrated`,
-    `satisfied`, `excited`, `polite`, `impolite`, and `sympathetic`. The service returns
-    results only for tones whose scores meet a minimum threshold of 0.5.
+    The service returns results only for tones whose scores meet a minimum threshold of
+    0.5.
     :attr str tone_name: The user-visible, localized name of the tone.
     """
 
@@ -645,10 +656,8 @@ class ToneChatScore(object):
         greater than 0.75 indicates a high likelihood that the tone is perceived in the
         utterance.
         :param str tone_id: The unique, non-localized identifier of the tone for the
-        results. The service can return results for the following tone IDs: `sad`,
-        `frustrated`, `satisfied`, `excited`, `polite`, `impolite`, and `sympathetic`. The
-        service returns results only for tones whose scores meet a minimum threshold of
-        0.5.
+        results. The service returns results only for tones whose scores meet a minimum
+        threshold of 0.5.
         :param str tone_name: The user-visible, localized name of the tone.
         """
         self.score = score
@@ -663,8 +672,7 @@ class ToneChatScore(object):
             args['score'] = _dict.get('score')
         else:
             raise ValueError(
-                'Required property \'score\' not present in ToneChatScore JSON'
-            )
+                'Required property \'score\' not present in ToneChatScore JSON')
         if 'tone_id' in _dict:
             args['tone_id'] = _dict.get('tone_id')
         else:
@@ -825,8 +833,7 @@ class ToneScore(object):
             args['tone_name'] = _dict.get('tone_name')
         else:
             raise ValueError(
-                'Required property \'tone_name\' not present in ToneScore JSON'
-            )
+                'Required property \'tone_name\' not present in ToneScore JSON')
         return cls(**args)
 
     def _to_dict(self):
