@@ -31,6 +31,9 @@ from .version import __version__
 BEARER = 'Bearer'
 X_WATSON_AUTHORIZATION_TOKEN = 'X-Watson-Authorization-Token'
 AUTH_HEADER_DEPRECATION_MESSAGE = 'Authenticating with the X-Watson-Authorization-Token header is deprecated. The token continues to work with Cloud Foundry services, but is not supported for services that use Identity and Access Management (IAM) authentication.'
+ICP_PREFIX = 'icp-'
+APIKEY = 'apikey'
+APIKEY_DEPRECATION_MESSAGE = 'Authenticating with apikey is deprecated. Move to using Identity and Access Management (IAM) authentication.'
 
 # Uncomment this to enable http debugging
 # try:
@@ -113,16 +116,16 @@ def string_to_datetime(string):
     return date_parser.parse(string)
 
 
-def _cleanup_param_value(value):
+def _cleanup_value(value):
     if isinstance(value, bool):
         return 'true' if value else 'false'
     return value
 
 
-def _cleanup_param_values(dictionary):
+def _cleanup_values(dictionary):
     if isinstance(dictionary, dict):
         return dict(
-            [(k, _cleanup_param_value(v)) for k, v in dictionary.items()])
+            [(k, _cleanup_value(v)) for k, v in dictionary.items()])
     return dictionary
 
 
@@ -177,10 +180,12 @@ class DetailedResponse(object):
 
     :param Response response: Either json response or http Response as requested.
     :param dict headers: A dict of response headers
+    :param str status_code: HTTP response code
     """
-    def __init__(self, response=None, headers=None):
+    def __init__(self, response=None, headers=None, status_code=None):
         self.result = response
         self.headers = headers
+        self.status_code = status_code
 
     def get_result(self):
         return self.result
@@ -188,21 +193,26 @@ class DetailedResponse(object):
     def get_headers(self):
         return self.headers
 
+    def get_status_code(self):
+        return self.status_code
+
     def _to_dict(self):
         _dict = {}
         if hasattr(self, 'result') and self.result is not None:
             _dict['result'] = self.result if isinstance(self.result, dict) else 'HTTP response'
         if hasattr(self, 'headers') and self.headers is not None:
             _dict['headers'] = self.headers
+        if hasattr(self, 'status_code') and self.status_code is not None:
+            _dict['status_code'] = self.status_code
         return _dict
 
     def __str__(self):
-        return json_import.dumps(self._to_dict(), indent=2, default=lambda o: o.__dict__)
+        return json_import.dumps(self._to_dict(), indent=4, default=lambda o: o.__dict__)
 
 class WatsonService(object):
     def __init__(self, vcap_services_name, url, username=None, password=None,
                  use_vcap_services=True, api_key=None,
-                 iam_api_key=None, iam_access_token=None, iam_url=None):
+                 iam_apikey=None, iam_access_token=None, iam_url=None):
         """
         Loads credentials from the VCAP_SERVICES environment variable if
         available, preferring credentials explicitly
@@ -219,11 +229,12 @@ class WatsonService(object):
         self.password = None
         self.default_headers = None
         self.http_config = {}
-        self.detailed_response = False
-        self.iam_api_key = None
+        self.detailed_response = True
+        self.iam_apikey = None
         self.iam_access_token = None
         self.iam_url = None
         self.token_manager = None
+        self.verify = None # Indicates whether to ignore verifying the SSL certification
 
         user_agent_string = 'watson-apis-python-sdk-' + __version__ # SDK version
         user_agent_string += ' ' + platform.system() # OS
@@ -234,12 +245,12 @@ class WatsonService(object):
         if api_key is not None:
             self.set_api_key(api_key)
         elif username is not None and password is not None:
-            if username in ('apikey', 'apiKey'):
+            if username is APIKEY and not password.startswith(ICP_PREFIX):
                 self.set_token_manager(password, iam_access_token, iam_url)
             else:
                 self.set_username_and_password(username, password)
-        elif iam_access_token is not None or iam_api_key is not None:
-            self.set_token_manager(iam_api_key, iam_access_token, iam_url)
+        elif iam_access_token is not None or iam_apikey is not None:
+            self.set_token_manager(iam_apikey, iam_access_token, iam_url)
 
         if use_vcap_services and not self.username and not self.api_key:
             self.vcap_service_credentials = load_from_vcap_services(
@@ -248,19 +259,15 @@ class WatsonService(object):
                     self.vcap_service_credentials, dict):
                 self.url = self.vcap_service_credentials['url']
                 if 'username' in self.vcap_service_credentials:
-                    self.username = self.vcap_service_credentials['username']
+                    self.username = self.vcap_service_credentials.get('username')
                 if 'password' in self.vcap_service_credentials:
-                    self.password = self.vcap_service_credentials['password']
+                    self.password = self.vcap_service_credentials.get('password')
                 if 'apikey' in self.vcap_service_credentials:
-                    self.api_key = self.vcap_service_credentials['apikey']
-                if 'api_key' in self.vcap_service_credentials:
-                    self.api_key = self.vcap_service_credentials['api_key']
-                if ('iam_api_key' or 'apikey')  in self.vcap_service_credentials:
-                    self.iam_api_key = self.vcap_service_credentials.get('iam_api_key') or self.vcap_service_credentials.get('apikey')
+                    self.set_iam_apikey(self.vcap_service_credentials.get('apikey'))
+                if 'iam_apikey' in self.vcap_service_credentials:
+                    self.set_iam_apikey(self.vcap_service_credentials.get('iam_apikey'))
                 if 'iam_access_token' in self.vcap_service_credentials:
-                    self.iam_access_token = self.vcap_service_credentials['iam_access_token']
-                if 'iam_url' in self.vcap_service_credentials:
-                    self.iam_url = self.vcap_service_credentials['iam_url']
+                    self.set_iam_access_token(self.vcap_service_credentials.get('iam_access_token'))
 
         if (self.username is None or self.password is None)\
                 and self.api_key is None and self.token_manager is None:
@@ -279,8 +286,13 @@ class WatsonService(object):
         self.jar = CookieJar()
 
     def set_api_key(self, api_key):
+        if api_key is not None:
+            warnings.warn(APIKEY_DEPRECATION_MESSAGE)
         if api_key == 'YOUR API KEY':
             api_key = None
+        if api_key is not None and api_key.startswith(ICP_PREFIX):
+            self.set_username_and_password(APIKEY, api_key)
+            return
 
         self.api_key = api_key
 
@@ -289,14 +301,14 @@ class WatsonService(object):
             self.set_url('https://gateway-a.watsonplatform.net/visual-recognition/api')
         self.jar = CookieJar()
 
-    def set_token_manager(self, iam_api_key=None, iam_access_token=None, iam_url=None):
-        if iam_api_key == 'YOUR IAM API KEY':
-            iam_api_key = None
+    def set_token_manager(self, iam_apikey=None, iam_access_token=None, iam_url=None):
+        if iam_apikey == 'YOUR IAM API KEY':
+            return
 
-        self.iam_api_key = iam_api_key
+        self.iam_apikey = iam_apikey
         self.iam_access_token = iam_access_token
         self.iam_url = iam_url
-        self.token_manager = IAMTokenManager(iam_api_key, iam_access_token, iam_url)
+        self.token_manager = IAMTokenManager(iam_apikey, iam_access_token, iam_url)
         self.jar = CookieJar()
 
     def set_iam_access_token(self, iam_access_token):
@@ -307,12 +319,12 @@ class WatsonService(object):
         self.iam_access_token = iam_access_token
         self.jar = CookieJar()
 
-    def set_iam_api_key(self, iam_api_key):
+    def set_iam_apikey(self, iam_apikey):
         if self.token_manager:
-            self.token_manager.set_iam_api_key(iam_api_key)
+            self.token_manager.set_iam_apikey(iam_apikey)
         else:
-            self.token_manager = IAMTokenManager(iam_api_key=iam_api_key)
-        self.iam_api_key = iam_api_key
+            self.token_manager = IAMTokenManager(iam_apikey=iam_apikey)
+        self.iam_apikey = iam_apikey
         self.jar = CookieJar()
 
     def set_url(self, url):
@@ -337,6 +349,9 @@ class WatsonService(object):
         else:
             raise TypeError("http_config parameter must be a dictionary")
 
+    def disable_SSL_verification(self):
+        self.verify = False
+
     def set_detailed_response(self, detailed_response):
         self.detailed_response = detailed_response
 
@@ -390,8 +405,8 @@ class WatsonService(object):
     def request(self, method, url, accept_json=False, headers=None,
                 params=None, json=None, data=None, files=None, **kwargs):
         full_url = self.url + url
-
         input_headers = _remove_null_values(headers) if headers else {}
+        input_headers = _cleanup_values(input_headers)
 
         headers = CaseInsensitiveDict(self.user_agent_header)
         if self.default_headers is not None:
@@ -405,7 +420,7 @@ class WatsonService(object):
 
         # Remove keys with None values
         params = _remove_null_values(params)
-        params = _cleanup_param_values(params)
+        params = _cleanup_values(params)
         json = _remove_null_values(json)
         data = _remove_null_values(data)
         files = _remove_null_values(files)
@@ -433,7 +448,14 @@ class WatsonService(object):
             else:
                 params['api_key'] = self.api_key
 
+        # Use a one minute timeout when our caller doesn't give a timeout.
+        # http://docs.python-requests.org/en/master/user/quickstart/#timeouts
+        kwargs = dict({"timeout": 60}, **kwargs)
         kwargs = dict(kwargs, **self.http_config)
+
+        if self.verify is not None:
+            kwargs['verify'] = self.verify
+
         response = requests.request(method=method, url=full_url,
                                     cookies=self.jar, auth=auth,
                                     headers=headers,
@@ -441,10 +463,15 @@ class WatsonService(object):
                                     **kwargs)
 
         if 200 <= response.status_code <= 299:
-            if response.status_code == 204:
-                return DetailedResponse(None, response.headers) if self.detailed_response else None
+            if response.status_code == 204 or method == 'HEAD':
+                # There is no body content for a HEAD request or a 204 response
+                return DetailedResponse(None, response.headers, response.status_code) if self.detailed_response else None
             if accept_json:
-                response_json = response.json()
+                try:
+                    response_json = response.json()
+                except:
+                    # deserialization fails because there is no text
+                    return DetailedResponse(None, response.headers, response.status_code) if self.detailed_response else None
                 if 'status' in response_json and response_json['status'] \
                         == 'ERROR':
                     status_code = 400
@@ -455,8 +482,8 @@ class WatsonService(object):
                     if error_message == 'invalid-api-key':
                         status_code = 401
                     raise WatsonApiException(status_code, error_message, httpResponse=response)
-                return DetailedResponse(response_json, response.headers) if self.detailed_response else response_json
-            return DetailedResponse(response, response.headers) if self.detailed_response else response
+                return DetailedResponse(response_json, response.headers, response.status_code) if self.detailed_response else response_json
+            return DetailedResponse(response, response.headers, response.status_code) if self.detailed_response else response
         else:
             if response.status_code == 401:
                 error_message = 'Unauthorized: Access is denied due to ' \
